@@ -60,14 +60,14 @@ pub fn available_line_width(
     config: &Config,
     data: &line_numbers::LineNumbersData,
 ) -> line_numbers::SideBySideLineWidth {
-    let linennumbers_width = data.formatted_width();
+    let line_numbers_width = data.formatted_width();
 
     // The width can be reduced by the line numbers and/or
     // a possibly added/restored 1-wide "+/-/ " prefix.
     let line_width = |side: PanelSide| {
         config.side_by_side_data[side]
             .width
-            .saturating_sub(linennumbers_width[side])
+            .saturating_sub(line_numbers_width[side])
             .saturating_sub(config.keep_plus_minus_markers as usize)
     };
 
@@ -526,6 +526,7 @@ fn pad_panel_line_to_width<'a>(
         }
         Some(BgFillMethod::Spaces) if text_width >= panel_width => (),
         Some(BgFillMethod::Spaces) => panel_line.push_str(
+            #[allow(clippy::unnecessary_to_owned)]
             &fill_style
                 .paint(" ".repeat(panel_width - text_width))
                 .to_string(),
