@@ -7,7 +7,7 @@ use sysinfo::{Pid, PidExt, Process, ProcessExt, ProcessRefreshKind, SystemExt};
 
 pub type DeltaPid = u32;
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub enum CallingProcess {
     GitDiff(CommandLine),
     GitShow(CommandLine, Option<String>), // element 2 is file extension
@@ -32,7 +32,7 @@ impl CallingProcess {
     }
 }
 
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub struct CommandLine {
     pub long_options: HashSet<String>,
     pub short_options: HashSet<String>,
@@ -100,7 +100,7 @@ fn determine_calling_process() -> CallingProcess {
 
 // Return value of `extract_args(args: &[String]) -> ProcessArgs<T>` function which is
 // passed to `calling_process_cmdline()`.
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Eq)]
 pub enum ProcessArgs<T> {
     // A result has been successfully extracted from args.
     Args(T),
@@ -298,6 +298,7 @@ impl ProcInfo {
 trait ProcActions {
     fn cmd(&self) -> &[String];
     fn parent(&self) -> Option<DeltaPid>;
+    fn pid(&self) -> DeltaPid;
     fn start_time(&self) -> u64;
 }
 
@@ -311,6 +312,9 @@ where
     fn parent(&self) -> Option<DeltaPid> {
         ProcessExt::parent(self).map(|p| p.as_u32())
     }
+    fn pid(&self) -> DeltaPid {
+        ProcessExt::pid(self).as_u32()
+    }
     fn start_time(&self) -> u64 {
         ProcessExt::start_time(self)
     }
@@ -450,29 +454,41 @@ where
 
     let my_pid = info.my_pid();
 
-    // 1) Try the parent process. If delta is set as the pager in git, then git is the parent process.
-    let parent = info.parent_process(my_pid)?;
+    // 1) Try the parent process(es). If delta is set as the pager in git, then git is the parent process.
+    // If delta is started by a script check the parent's parent as well.
+    let mut current_pid = my_pid;
+    'parent_iter: for depth in [1, 2, 3] {
+        let parent = match info.parent_process(current_pid) {
+            None => {
+                break 'parent_iter;
+            }
+            Some(parent) => parent,
+        };
+        let parent_pid = parent.pid();
 
-    match extract_args(parent.cmd()) {
-        ProcessArgs::Args(result) => return Some(result),
-        ProcessArgs::ArgError => return None,
+        match extract_args(parent.cmd()) {
+            ProcessArgs::Args(result) => return Some(result),
+            ProcessArgs::ArgError => return None,
 
-        // 2) The parent process was something else, this can happen if git output is piped into delta, e.g.
-        // `git blame foo.txt | delta`. When the shell sets up the pipe it creates the two processes, the pids
-        // are usually consecutive, so check if the process with `my_pid - 1` matches.
-        ProcessArgs::OtherProcess => {
-            let sibling = info.naive_sibling_process(my_pid);
-            if let Some(proc) = sibling {
-                if let ProcessArgs::Args(result) = extract_args(proc.cmd()) {
-                    return Some(result);
+            // 2) The 1st parent process was something else, this can happen if git output is piped into delta, e.g.
+            // `git blame foo.txt | delta`. When the shell sets up the pipe it creates the two processes, the pids
+            // are usually consecutive, so naively check if the process with `my_pid - 1` matches.
+            ProcessArgs::OtherProcess if depth == 1 => {
+                let sibling = info.naive_sibling_process(current_pid);
+                if let Some(proc) = sibling {
+                    if let ProcessArgs::Args(result) = extract_args(proc.cmd()) {
+                        return Some(result);
+                    }
                 }
             }
-            // else try the fallback
+            // This check is not done for the parent's parent etc.
+            ProcessArgs::OtherProcess => {}
         }
+        current_pid = parent_pid;
     }
 
     /*
-    3) Neither parent nor direct sibling were a match.
+    3) Neither parent(s) nor the direct sibling were a match.
     The most likely case is that the input program of the pipe wrote all its data and exited before delta
     started, so no command line can be parsed. Same if the data was piped from an input file.
 
@@ -498,18 +514,34 @@ where
 
     */
 
-    let pid_range = my_pid.saturating_sub(10)..my_pid.saturating_add(20);
+    // Also `add` because `A_has_pid101 | delta_has_pid102`, but if A is a wrapper which then calls
+    // git (no `exec`), then the final pid of the git process might be 103 or greater.
+    let pid_range = my_pid.saturating_sub(10)..my_pid.saturating_add(10);
     for p in pid_range {
         // Processes which were not refreshed do not exist for sysinfo, so by selectively
         // letting it know about processes the `find_sibling..` function will only
         // consider these.
-        info.refresh_process(p);
+        if info.process(p).is_none() {
+            info.refresh_process(p);
+        }
     }
 
     match info.find_sibling_in_refreshed_processes(my_pid, &extract_args) {
         None => {
-            info.refresh_processes();
-            info.find_sibling_in_refreshed_processes(my_pid, &extract_args)
+            #[cfg(not(target_os = "linux"))]
+            let full_scan = true;
+
+            // The full scan is expensive on Linux and rarely successful, so disable it by default.
+            #[cfg(target_os = "linux")]
+            let full_scan = std::env::var("DELTA_CALLING_PROCESS_QUERY_ALL")
+                .map_or(false, |v| !["0", "false", "no"].iter().any(|&n| n == v));
+
+            if full_scan {
+                info.refresh_processes();
+                info.find_sibling_in_refreshed_processes(my_pid, &extract_args)
+            } else {
+                None
+            }
         }
         some => some,
     }
@@ -566,7 +598,7 @@ pub mod tests {
     // When calling `FakeParentArgs::get()`, it can return `Some(values)` which were set earlier
     // during in the #[test]. Otherwise returns None.
     // This value can be valid once: `FakeParentArgs::once(val)`, for the entire scope:
-    // `FakeParentArgs::for_scope(val)`, or can be different values everytime `get()` is called:
+    // `FakeParentArgs::for_scope(val)`, or can be different values every time `get()` is called:
     // `FakeParentArgs::with([val1, val2, val3])`.
     // It is an error if `once` or `with` values remain unused, or are overused.
     // Note: The values are stored per-thread, so the expectation is that no thread boundaries are
@@ -750,6 +782,9 @@ pub mod tests {
         fn parent(&self) -> Option<DeltaPid> {
             self.ppid
         }
+        fn pid(&self) -> DeltaPid {
+            self.pid
+        }
         fn start_time(&self) -> u64 {
             self.start_time
         }
@@ -855,7 +890,7 @@ pub mod tests {
     fn test_process_testing_assert_never_used() {
         let _args = FakeParentArgs::once("never used");
 
-        // causes a panic while panicing, so can't test:
+        // causes a panic while panicking, so can't test:
         // let _args = FakeParentArgs::for_scope(&"never used");
         // let _args = FakeParentArgs::once(&"never used");
     }
@@ -904,7 +939,7 @@ pub mod tests {
             calling_process_cmdline(ProcInfo::new(), guess_git_blame_filename_extension),
             Some("once".into())
         );
-        // ignored: dropping causes a panic while panicing, so can't test
+        // ignored: dropping causes a panic while panicking, so can't test
         calling_process_cmdline(ProcInfo::new(), guess_git_blame_filename_extension);
     }
 
@@ -1160,7 +1195,7 @@ pub mod tests {
         }
 
         // Tests that caller is something like "cargo test" or "cargo tarpaulin"
-        let find_test = |args: &[String]| find_calling_process(args, &["test", "tarpaulin"]);
+        let find_test = |args: &[String]| find_calling_process(args, &["t", "test", "tarpaulin"]);
         assert_eq!(calling_process_cmdline(info, find_test), Some(()));
 
         let nonsense = ppid_distance
